# Permission Resolver

A zero-dependency RBAC + ABAC permission resolving engine for any Node.js or TypeScript application.

> Easily use it in Express, NestJS, React, or microservices.

---

## Installation

```bash
npm install @ymerncloud/permission-resolver
```

## Usage

```bash

import {
  PermissionResolver,
  Subject,
  Resource,
  PermissionRule,
} from "@merncloud/permission-resolver";

const rules: PermissionRule[] = [
  {
    resource: "document",
    action: "read",
    allowedRoles: ["editor"],
    attributeCondition: {
      and: [
        { "==": [{ var: "subject.team" }, { var: "resource.team" }] },
        { ">=": [{ var: "subject.level" }, 2] },
      ],
    },
  },
];

const subject: Subject = {
  id: "user-1",
  roles: ["editor"],
  attributes: { team: "alpha", level: 3 },
};

const resource: Resource = {
  id: "doc-1",
  type: "document",
  attributes: { team: "alpha" },
};

const resolver = new PermissionResolver(rules);

const canRead = resolver.can(subject, resource, "read");

console.log("✅ Can Read:", canRead);


```
